@@ -72,19 +72,36 @@ BayonneBinder("troll")
 		} 
 	}
 #endif
+#ifdef	WIN32
+        server->setValue("service.conf", CONFIG_FILES "/service.ini");
+        server->setValue("macro.func", CONFIG_FILES "/macro.ini"); 
+        server->setValue("exec.func", CONFIG_FILES "/exec.ini"); 
+#else
 	server->setValue("service.conf", CONFIG_FILES "/service.conf");
 	server->setValue("macro.func", CONFIG_FILES "/macro.conf");
 	server->setValue("exec.func", CONFIG_FILES "/exec.conf");
+#endif
 	if(BayonneDriver::getTrunking() != NULL)
 	{
+#ifdef	WIN32
+                server->setValue("caller.ini", CONFIG_FILES "/caller.conf");
+                server->setValue("dialed.ini", CONFIG_FILES "/dialed.conf");
+        	server->setValue("timeslot.ini", CONFIG_FILES "/timeslot.conf");
+                server->setValue("span.ini", CONFIG_FILES "/span.conf");
+                server->setValue("dialing.ini", CONFIG_FILES "/dialing.conf");
+        }
+        if(BayonneDriver::getProtocol() != NULL)
+                server->setValue("routing.ini", CONFIG_FILES "/routing.conf"); 
+#else
 		server->setValue("caller.conf", CONFIG_FILES "/caller.conf");
 		server->setValue("dialed.conf", CONFIG_FILES "/dialed.conf");
-		server->setValue("timeslot.conf", CONFIG_FILES "/timeslot.conf");
+	server->setValue("timeslot.conf", CONFIG_FILES "/timeslot.conf");
 		server->setValue("span.conf", CONFIG_FILES "/span.conf");
 		server->setValue("dialing.conf", CONFIG_FILES "/dialing.conf");
 	}
 	if(BayonneDriver::getProtocol() != NULL)
 		server->setValue("routing.conf", CONFIG_FILES "/routing.conf");
+#endif
 };
 
 const char *Binder::altPath(const char *scr)
