@@ -1027,6 +1027,16 @@ public:
          */
 	virtual unsigned saycount(BayonneSession *session, unsigned count, const char *string);
 
+	/**
+	 * Translate a string for time into short hours.
+	 *
+	 * @param session to save list of prompts.
+	 * @param count of current prompts used.
+	 * @param string to be processed.
+	 * @return new count of prompts used.
+	 */
+	virtual unsigned sayhour(BayonneSession *session, unsigned count, const char *string);
+
         /**
          * Translate a string for time into speech.
          *
@@ -1047,6 +1057,16 @@ public:
          */
 	virtual unsigned weekday(BayonneSession *session, unsigned count, const char *string);
 
+	/**
+	 * Translate a string with a date into spoken date without year.
+	 *
+	 * @param session to save list of prompts.
+	 * @param count of current prompts used.
+	 * @param string to be processed.
+	 * @return new count of prompts used.
+	 */
+	virtual unsigned sayday(BayonneSession *session, unsigned count, const char *string); 
+
         /**
          * Translate a string with a date into a spoken date.
          *
