@@ -144,6 +144,57 @@ unsigned BayonneTranslator::saydate(BayonneSession *s, unsigned count, const cha
 	return count;
 }
 
+unsigned BayonneTranslator::sayday(BayonneSession *s, unsigned count, const char *cp)
+{
+        int month, day, year;
+	char buf[8];
+
+	year = month = day = 0;
+
+	if(count > MAX_LIST - 16)
+		return count;
+
+	if(strchr(cp, '-'))
+	{
+		year = atoi(cp);
+		cp = strchr(cp, '-');
+		if(cp)
+			month = atoi(++cp);
+		if(cp)
+			cp = strchr(cp, '-');
+		if(cp)
+			day = atoi(++cp);
+	}
+	else if(strchr(cp, '/'))
+	{
+		month = atoi(cp);
+		cp = strchr(cp, '/');
+		if(cp)
+			day = atoi(++cp);
+		if(cp)
+			cp = strchr(cp, '/');
+		if(cp)
+			year = atoi(++cp);
+	}
+	else if(strchr(cp, '.'))
+	{
+		day = atoi(cp);
+		cp = strchr(cp, '.');
+		if(cp)
+			month = atoi(++cp);
+		if(cp)
+			cp = strchr(cp, '.');
+		if(cp)
+			year = atoi(++cp);
+	}
+	else return count;
+
+        --month;
+	s->state.audio.list[count++] = months[month];
+	snprintf(buf, sizeof(buf), "%d", day);
+	return sayorder(s, count, buf);
+}
+
 unsigned BayonneTranslator::weekday(BayonneSession *s, unsigned count,
 const char *cp) {
 	time_t cl;
@@ -429,6 +480,39 @@ unsigned BayonneTranslator::saytime(BayonneSession *s, unsigned count, const cha
 	return count;
 }
 
+unsigned BayonneTranslator::sayhour(BayonneSession *s, unsigned count, const char *cp)
+{
+	int hour = 0;
+	int min = 0;
+	bool pm = false;
+	char buf[4];
+
+	if(!cp || count > MAX_LIST - 10)
+		return count;
+
+	hour = atoi(cp);
+	cp = strchr(cp, ':');
+	if(cp)
+		min = atoi(++cp);
+
+	if(hour > 11)
+	{
+		pm = true;
+		hour -= 12;
+	}
+	if(!hour)
+		hour = 12;
+
+	snprintf(buf, sizeof(buf), "%d", hour);
+	count = number(s, count, buf);
+	if(pm)
+		s->state.audio.list[count++] = "p";
+	else
+		s->state.audio.list[count++] = "a";
+	s->state.audio.list[count++] = "m";
+	return count;
+}
+
 unsigned BayonneTranslator::addItem(BayonneSession *s, unsigned count, const char *text)
 {
 	s->state.audio.list[count++] = text;
@@ -489,8 +573,18 @@ const char *BayonneTranslator::speak(BayonneSession *s, Line *l)
 			count = saybool(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&time"))
 			count = saytime(s, count, getToken(s, l, &idx));
+		else if(!stricmp(cp, "&hour"))
+			count = sayhour(s, count, getToken(s, l, &idx));
 		else if(!stricmp(cp, "&weekday"))
 			count = weekday(s, count, getToken(s, l, &idx));
+		else if(!stricmp(cp, "&day"))
+			count = sayday(s, count, getToken(s, l, &idx));
+		else if(!stricmp(cp, "&daydate"))
+		{
+			cp = getToken(s, l, &idx);
+			count = weekday(s, count, cp);
+			count = sayday(s, count, cp);
+		}
 		else if(!stricmp(cp, "&fulldate"))
 		{
 			cp = getToken(s, l, &idx);
