@@ -24,6 +24,7 @@ using namespace std;
 static class EnglishTranslator : public BayonneTranslator
 {
 public:
+	unsigned sayhour(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saytime(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saydate(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saynumber(BayonneSession *s, unsigned count, const char *cp);
@@ -34,6 +35,7 @@ public:
 static class UsEnglishTranslator : public EnglishTranslator
 {
 public:
+	unsigned sayhour(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saydate(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saytime(BayonneSession *s, unsigned count, const char *cp);
 	UsEnglishTranslator();
@@ -49,6 +51,11 @@ unsigned UsEnglishTranslator::saytime(BayonneSession *s, unsigned count, const c
 	return BayonneTranslator::saytime(s, count, cp);
 }
 
+unsigned UsEnglishTranslator::sayhour(BayonneSession *s, unsigned count, const char *cp)
+{
+	return BayonneTranslator::sayhour(s, count, cp);
+}
+
 static char *months[] = {"january", "february", "march", "april",
         "may", "june", "july", "august",
         "september", "october", "november", "december"};  
@@ -211,6 +218,11 @@ unsigned EnglishTranslator::saytime(BayonneSession *s, unsigned count, const cha
         return count;   
 }
 
+unsigned EnglishTranslator::sayhour(BayonneSession *s, unsigned count, const char *cp)
+{
+	return EnglishTranslator::saytime(s, count, cp);
+}
+
 EnglishTranslator::EnglishTranslator(const char *cp) :
 BayonneTranslator(cp)
 {
