@@ -29,6 +29,8 @@ private:
 	unsigned sayorder(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saydate(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saytime(BayonneSession *s, unsigned count, const char *cp);
+	unsigned sayday(BayonneSession *s, unsigned count, const char *cp);
+	unsigned sayhour(BayonneSession *s, unsigned count, const char *cp);
 
 public:
 	ItalianTranslator();
@@ -55,7 +57,7 @@ static char *ends[] = {"0end", "1end", "2end", "3end", "4end", "5end",
         "6end", "7end", "8end", "9end", "10end", "11end", "12end",
         "13end", "14end", "15end", "16end", "17end", "18end", "19end"}; 
 
-static char *months[] = {"january", "februrary", "march", "april",
+static char *months[] = {"january", "february", "march", "april",
 	"may", "june", "july", "august",
 	"september", "october", "november", "december"};
 
@@ -91,6 +93,11 @@ unsigned ItalianTranslator::number(BayonneSession *s, unsigned count, const char
 	return count;
 }
 
+unsigned ItalianTranslator::sayhour(BayonneSession *s, unsigned count, const char *cp)
+{
+	return ItalianTranslator::saytime(s, count, cp);
+}
+
 unsigned ItalianTranslator::saytime(BayonneSession *s, unsigned count, const char *cp)
 {
         int hour = 0;
@@ -167,6 +174,56 @@ unsigned ItalianTranslator::saydate(BayonneSession *s, unsigned count, const cha
 	return saynumber(s, count, buf);
 }
 
+unsigned ItalianTranslator::sayday(BayonneSession *s, unsigned count, const char *cp)
+{
+        int month, day, year;      
+        char buf[8];
+
+        year = month = day = 0;
+
+        if(count > MAX_LIST - 16)
+                return count;  
+                          
+        if(strchr(cp, '-'))
+        {
+                year = atoi(cp);
+                cp = strchr(cp, '-');
+                if(cp)
+                        month = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '-');
+                if(cp)
+                        day = atoi(++cp);
+        } 
+        else if(strchr(cp, '/'))
+        {
+                month = atoi(cp);
+                cp = strchr(cp, '/');
+                if(cp)
+                        day = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '/');
+                if(cp)
+                        year = atoi(++cp);
+        } 
+        else if(strchr(cp, '.'))
+        {
+                day = atoi(cp);
+                cp = strchr(cp, '.');
+                if(cp)
+                        month = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '.');
+                if(cp)
+                        year = atoi(++cp);
+        }
+        else return count;   
+        --month;
+	snprintf(buf, sizeof(buf), "%d", day); 
+	count = sayorder(s, count, buf);
+	return addItem(s, count, months[month]);
+}
+
 unsigned ItalianTranslator::sayorder(BayonneSession *s, unsigned count, const char *cp)
 {
 	long num = atol(cp);
