@@ -33,6 +33,8 @@ private:
 	unsigned saynumber(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saydate(BayonneSession *s, unsigned count, const char *cp);
 	unsigned saytime(BayonneSession *s, unsigned count, const char *cp);
+	unsigned sayday(BayonneSession *s, unsigned count, const char *cp);
+	unsigned sayhour(BayonneSession *s, unsigned count, const char *cp);
 	unsigned sayorder(BayonneSession *s, unsigned count, const char *cp);
 	unsigned spell(BayonneSession *s, unsigned count, const char *cp);
 
@@ -198,6 +200,11 @@ unsigned RussianTranslator::spell(BayonneSession *s, unsigned count, const char
         return count;
 } 
 
+unsigned RussianTranslator::sayhour(BayonneSession *s, unsigned count, const char *cp)
+{
+	return RussianTranslator::saytime(s, count, cp);
+}
+
 unsigned RussianTranslator::number(BayonneSession *s, unsigned count, const char *cp)
 {
 	long num = atol(cp);
@@ -557,6 +564,56 @@ unsigned RussianTranslator::saydate(BayonneSession *s, unsigned count, const cha
 	return addItem(s, count, "god-case_1");
 }
 
+unsigned RussianTranslator::sayday(BayonneSession *s, unsigned count, const char *cp)
+{
+        int month, day, year;      
+        char buf[8];
+
+        year = month = day = 0;
+
+        if(count > MAX_LIST - 16)
+                return count;  
+                          
+        if(strchr(cp, '-'))
+        {
+                year = atoi(cp);
+                cp = strchr(cp, '-');
+                if(cp)
+                        month = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '-');
+                if(cp)
+                        day = atoi(++cp);
+        } 
+        else if(strchr(cp, '/'))
+        {
+                month = atoi(cp);
+                cp = strchr(cp, '/');
+                if(cp)
+                        day = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '/');
+                if(cp)
+                        year = atoi(++cp);
+        } 
+        else if(strchr(cp, '.'))
+        {
+                day = atoi(cp);
+                cp = strchr(cp, '.');
+                if(cp)
+                        month = atoi(++cp);
+                if(cp)
+                        cp = strchr(cp, '.');
+                if(cp)
+                        year = atoi(++cp);
+        }
+        else return count;   
+        --month;
+	snprintf(buf, sizeof(buf), "%d", day); 
+	count = number_neuter(s, count, buf);
+	return addItem(s, count, months[month]);
+}
+
 unsigned RussianTranslator::saynumber(BayonneSession *s, unsigned count, const char *cp)
 {
         long num;
