@@ -889,7 +889,7 @@ skip:
 			keyoptions.setValue("modules", *argv);
 		else if(!stricmp(ext, ".conf") || !stricmp(ext, ".ini"))
 			slog.error("bayonne: %s: invalid script file", *argv);
-		else if(!stricmp(ext, ".mac") || !stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext))
+		else if(!stricmp(ext, ".mac") || !stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext) || !stricmp(ext, ".def"))
 		{
 			prefix = strrchr(*argv, '/');
 			if(!prefix)
@@ -917,7 +917,10 @@ skip:
 				else
 					script = NULL;
 
-				runtime.setValue(*argv, prefix);
+				if(!stricmp(ext, ".def"))
+					runtime.setValue("definitions", prefix);
+				else
+					runtime.setValue(*argv, prefix);
 			}
 		}
 		else
